gammapy-info
------------

Code
++++

.. literalinclude:: ../../scripts/gammapy-info
    :language: python

Help output
+++++++++++

.. code-block:: bash

   $ gammapy-info -h
   usage: gammapy-info [-h] [--version] [--tools]
   
   Print various info on Gammapy to the console.
   
   TODO: explain.
   
   optional arguments:
     -h, --help  show this help message and exit
     --version   Print Gammapy version number (default: False)
     --tools     Print available command line tools (default: False)
